@@ -512,15 +512,12 @@ $vals{1}{111}{rotate_surface} =
 $vals{1}{111}{translate_vertices} = 
 [ 
 [ 
-[ "a", "i", "0\ny", "j",  "b", "f", "k", "l", "e",  "d", "0\nr", "0\na", "0\nq", "c", "g", "0\nt", "0\ns", "h" ],  
-[ [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0],  [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0] ], 
-[ "/zones/zone.geo" ], # source file
-[ "y" ] # long menus?
+[ 8, 15, 18, 7 ],  #vertex number
+[ [0, 0, 0.5], [0, 0, 0.5], [0, 0, 0.5], [0, 0, 0.5] ], #those values depend on the transformation type. See the vertex transform manu.
+#If transformation type = "c", the three values are: movement distance, azimuth and elevation.
+[ "/zones/new.geo" ], # source file
 ],
 ];
-# [ @vertexes_to_transl, Consider that after "p" you have to write "0\nq" ]
-# [ [ x y z movs ] ],  in case of surface x y z translation
-# source file, # long menus?
 
 
 $vals{1}{111}{rotate} = 
