@@ -28,7 +28,7 @@ $computype = "linear";
 # THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE. ONLY "linear will remain".
 # WHEN UNSPECIFIED, THE DEFAULT IS "linear".
 
-@calcprocedures = ( "complete", "halved" );
+@calcprocedures = ( "complete", "diluted" );
 # The options are the following:
 # "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff", "halved".
 # "main", "alternative", "complete" and "spreaddiff" can be combined with the other options. 
